API
===

.. module:: pygindex.client


Client
------

Price Resolution Settings
~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoenum:: IGPriceResolution
   :members:
   :inherited-members:

User Authentication Data Object
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: IGUserAuth
   :members:
   :inherited-members:

IG API Configuration Data Object
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: IGAPIConfig
   :members:
   :inherited-members:

Session Data Object
~~~~~~~~~~~~~~~~~~~

.. autoclass:: IGSession
   :members:
   :inherited-members:

Response Data Object
~~~~~~~~~~~~~~~~~~~~

.. autoclass:: IGResponse
   :members:
   :inherited-members:

Instrument Data Object
~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: IGInstrument
   :members:
   :inherited-members:

Instrument Historical Price Data Object
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: IGInstrumentPrices
   :members:
   :inherited-members:

Client Object
~~~~~~~~~~~~~

.. autoclass:: IGClient
   :members:
   :inherited-members:
